@@ -9,25 +9,24 @@ use Symbol;
 use File::Spec;
 use Carp;
 
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 __PACKAGE__->mk_classdata(dir => (__FILE__ =~ /(.+)\.pm/)[0]);
 __PACKAGE__->mk_classdata(languages => {});
 __PACKAGE__->mk_classdata('use_io_layer');
 
-use constant {
-    CODE => 0,
-    COUNTRY => 1,
+use constant CODE => 0;
+use constant COUNTRY => 1;
+use constant LOCALE_CODE_ALPHA_2 => 0;
+use constant LOCALE_CODE_ALPHA_3 => 1;
+use constant LOCALE_CODE_NUMERIC => 2;
+use constant MAP_LOCALE_CODE_STR_TO_IDX => {
     LOCALE_CODE_ALPHA_2 => 0,
     LOCALE_CODE_ALPHA_3 => 1,
     LOCALE_CODE_NUMERIC => 2,
-    MAP_LOCALE_CODE_STR_TO_IDX => {
-	LOCALE_CODE_ALPHA_2 => 0,
-	LOCALE_CODE_ALPHA_3 => 1,
-	LOCALE_CODE_NUMERIC => 2,
-    },
 };
 
+
 croak __PACKAGE__->dir, ": $!"
     unless -d __PACKAGE__->dir;
 
@@ -122,7 +121,7 @@ sub all_country_names {
     $lang ||= $self->{lang} || 'en';
     my $language = $self->_load_data($lang);
 
-    return keys %{ $language->[COUNTRY]->[LOCALE_CODE_ALPHA_2] };
+    return values %{ $language->[CODE]->[LOCALE_CODE_ALPHA_2] };
 }
 
 sub _load_data {
@@ -208,7 +207,7 @@ Locale::Country::Multilingual - mapping ISO codes to localized country names
     $country = $lcm->code2country('250');       # $country gets 'France'
     $code    = $lcm->country2code('Norway');    # $code gets 'no'
     
-    $lcm->set_lang('zh_CN'); # set default language to Chinese
+    $lcm->set_lang('zh'); # set default language to Chinese
     $country = $lcm->code2country('cn');        # $country gets '中国'
     $code    = $lcm->country2code('日本');      # $code gets 'jp'
     
@@ -218,7 +217,7 @@ Locale::Country::Multilingual - mapping ISO codes to localized country names
     # more heavy call
     my $lang = 'en';
     $country = $lcm->code2country('cn', $lang);        # $country gets 'China'
-    $lang = 'zh_CN';
+    $lang = 'zh';
     $country = $lcm->code2country('cn', $lang);        # $country gets '中国'
     
     my $CODE = 'LOCALE_CODE_ALPHA_2'; # by default
@@ -227,19 +226,21 @@ Locale::Country::Multilingual - mapping ISO codes to localized country names
     $code    = $lcm->country2code('Norway', $CODE);    # $code gets 'nor'
     $CODE = 'LOCALE_CODE_NUMERIC';
     $code    = $lcm->country2code('Norway', $CODE);    # $code gets '578'
-    $code    = $lcm->country2code('挪威', $CODE, 'zh_CN');    # with lang=zh_CN
+    $code    = $lcm->country2code('挪威', $CODE, 'zh');    # with lang=zh
     
     $CODE = 'LOCALE_CODE_ALPHA_3';
-    $lang = 'zh_CN';
+    $lang = 'zh';
     @codes   = $lcm->all_country_codes($CODE);         # return codes with 3alpha
     @names   = $lcm->all_country_names($lang);         # get all Chinese Countries Names
 
 =head1 DESCRIPTION
 
-C<Locale::Country::Multilingual> is nearly a drop-in replacement for
-L<Locale::Country|Locale::Country>, but supports country names in several
+C<Locale::Country::Multilingual> is an OO replacement for
+L<Locale::Country|Locale::Country>, that supports country names in several
 languages.
 
+=head2 Language Codes
+
 A language is selected by a two-letter language code as described by
 ISO 639-1 L<http://en.wikipedia.org/wiki/List_of_ISO_639-1_codes>.
 This code can be amended by a two-letter region code, that is described by
@@ -252,6 +253,14 @@ L<setlocale(3)> function. Codes can be given in small or capital letters
 and be divided by an arbitrary string of none-letter ASCII bytes (but
 C<"-"> or C<"_"> is recommended).
 
+=head2 Language Selection Fallback
+
+In case a language code contains a region, language selection falls back to
+the two-letter language code if no specific language file for the region
+exists. Example: For C<"zh_CN"> selection will fall back to C<"zh"> since
+there is no file F<"zh-cn.dat"> - actually C<"zh.dat"> happens to contain
+the country names in Simplified (Han) Chinese.
+
 =head1 METHODS
 
 =head2 import
@@ -324,7 +333,7 @@ this way:
 =head2 code2country
 
   $country = $lcm->code2country('gb');
-  $country = $lcm->code2country('gb', 'zh_CN');
+  $country = $lcm->code2country('gb', 'zh');
 
 Turns an ISO 3166-1 code into a country name in the current language.
 The default language is C<"en">.
@@ -362,13 +371,21 @@ This method L<croaks|Carp> if the language is not available.
 
 =head2 all_country_codes
 
+  @countrycodes = $lcm->all_country_codes;
+  @countrycodes = $lcm->all_country_codes($codeset);
+
+Returns an unsorted list of all ISO-3166 codes.
+
+The argument is optional and can be one of C<"LOCALE_CODE_ALPHA_2">,
+C<"LOCALE_CODE_ALPHA_3"> and C<"LOCALE_CODE_NUMERIC">. The default is
+C<"LOCALE_CODE_ALPHA2">.
+
 =head2 all_country_names
 
   @countrynames = $lcm->all_country_names;
   @countrynames = $lcm->all_country_names('fr');
 
-Returns an array of all lowercased country names in the current or given
-locale.
+Returns an unsorted list of country names in the current or given locale.
 
 =head1 AVAILABLE LANGAUGES
 
@@ -396,7 +413,7 @@ locale.
 
 =back
 
-other languages are welcome to send by email.
+Other languages are welcome to send by email.
 
 =head2 Deprecated languages
 
